==> firebase_repository-1.0.85.tar.gz: lib/src/entities/tratamiento_entity.dart <==

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class TratamientoEntity extends Equatable{
  final String uuid;
  final int cabezas;
  final List<dynamic> detalle;
  final DateTime fecha;
  final String tropaUuid;

  TratamientoEntity(this.uuid, this.cabezas, this.detalle, this.fecha, this.tropaUuid);

  Map<String, Object> toJson(){
    return{
      'uuid' : this.uuid,
      'cabezas': this.cabezas,
      'detalle': this.detalle,
      'fecha': this.fecha,
      'tropaUuid': this.tropaUuid
    };
  }

  @override
  String toString() {
    return 'TratamientoEntity{uuid: $uuid, cabezas: $cabezas, detalle: $detalle, fecha: $fecha, tropaUuid: $tropaUuid}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is TratamientoEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              cabezas == other.cabezas &&
              detalle == other.detalle &&
              fecha == other.fecha &&
              tropaUuid == other.tropaUuid;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      cabezas.hashCode ^
      detalle.hashCode ^
      fecha.hashCode ^
      tropaUuid.hashCode;

  static TratamientoEntity fromJson(Map<String, Object> json){
    return TratamientoEntity(
      json['uuid'] as String,
      json['cabezas'] as int,
      json['detalle'] as List<dynamic>,
      json['fecha'] as DateTime,
      json['tropaUuid'] as String
    );
  }

  TratamientoEntity.fromSnapshot(DocumentSnapshot snap)
  : uuid = snap.documentID,
    cabezas = snap.data['cabezas'],
    detalle = snap.data['detalle'],
    fecha = snap.data['fecha'] != null
        ? (snap.data['fecha'] is int ||
        snap.data['fecha'] is double)
        ? DateTime.fromMillisecondsSinceEpoch(
        snap.data['fecha'].round().toInt())
        : snap.data['fecha'].toDate()
        : null,
    tropaUuid = snap.data['tropaUuid'];

  Map<String, Object> toDocument(){
    return{
      'uuid' : this.uuid,
      'cabezas': this.cabezas,
      'detalle': this.detalle,
      'fecha': this.fecha,
      'tropaUuid': this.tropaUuid
    };
  }

}

==> firebase_repository-1.1.24.tar.gz: lib/src/entities/tratamiento_entity.dart <==

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class TratamientoEntity extends Equatable{
  final String uuid;
  final int cabezas;
  final List<dynamic> detalle;
  final DateTime fecha;
  final String tropaUuid;

  TratamientoEntity(this.uuid, this.cabezas, this.detalle, this.fecha, this.tropaUuid);

  Map<String, Object> toJson(){
    return{
      'uuid' : this.uuid,
      'cabezas': this.cabezas,
      'detalle': this.detalle,
      'fecha': this.fecha,
      'tropaUuid': this.tropaUuid
    };
  }

  @override
  String toString() {
    return 'TratamientoEntity{uuid: $uuid, cabezas: $cabezas, detalle: $detalle, fecha: $fecha, tropaUuid: $tropaUuid}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is TratamientoEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              cabezas == other.cabezas &&
              detalle == other.detalle &&
              fecha == other.fecha &&
              tropaUuid == other.tropaUuid;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      cabezas.hashCode ^
      detalle.hashCode ^
      fecha.hashCode ^
      tropaUuid.hashCode;

  static TratamientoEntity fromJson(Map<String, Object> json){
    return TratamientoEntity(
      json['uuid'] as String,
      json['cabezas'] as int,
      json['detalle'] as List<dynamic>,
      json['fecha'] as DateTime,
      json['tropaUuid'] as String
    );
  }

  TratamientoEntity.fromSnapshot(DocumentSnapshot snap)
  : uuid = snap.documentID,
    cabezas = snap.data['cabezas'].runtimeType == double ? int.parse(snap.data['cabezas'].toStringAsFixed(0)) : snap.data['cabezas'],
    detalle = snap.data['detalle'],
    fecha = snap.data['fecha'] != null
        ? (snap.data['fecha'] is int ||
        snap.data['fecha'] is double)
        ? DateTime.fromMillisecondsSinceEpoch(
        snap.data['fecha'].round().toInt())
        : snap.data['fecha'].toDate()
        : null,
    tropaUuid = snap.data['tropaUuid'];

  Map<String, Object> toDocument(){
    return{
      'cabezas': this.cabezas,
      'detalle': this.detalle,
      'fecha': this.fecha,
      'tropaUuid': this.tropaUuid
    };
  }

}
